{
    "$graph": [
        {
            "class": "Workflow",
            "label": "bulk scRNA-seq pipeline using Salmon",
            "inputs": [
                {
                    "label": "Directory containing FASTQ files",
                    "type": "Directory",
                    "id": "#main/fastq_dir"
                },
                {
                    "label": "Number of threads for Salmon",
                    "type": "int",
                    "default": 1,
                    "id": "#main/threads"
                }
            ],
            "steps": [
                {
                    "id": "#main/fastqc",
                    "in": [
                        {
                            "id": "#main/fastqc/fastq_dir",
                            "source": "#main/fastq_dir"
                        },
                        {
                            "id": "#main/fastqc/threads",
                            "source": "#main/threads"
                        }
                    ],
                    "out": [
                        "#main/fastqc/fastqc_dir"
                    ],
                    "run": "#fastqc.cwl",
                    "label": "Run fastqc on all fastq files in fastq directory"
                },
                {
                    "id": "#main/salmon-bulk",
                    "in": [
                        {
                            "id": "#main/salmon-bulk/fastq_dir",
                            "source": "#main/fastq_dir"
                        },
                        {
                            "id": "#main/salmon-bulk/threads",
                            "source": "#main/threads"
                        }
                    ],
                    "out": [
                        "#main/salmon-bulk/output_dir"
                    ],
                    "run": "#bulk-salmon.cwl",
                    "label": "Salmon quant 1.0.0, with index from GRCh38 transcriptome"
                },
                {
                    "id": "#main/make_expression_matrix",
                    "in": [
                        {
                            "id": "#main/make_expression_matrix/quant_dir",
                            "source": "#main/salmon-bulk/output_dir"
                        }
                    ],
                    "out": [
                        "#main/make_expression_matrix/expression_matrix"
                    ],
                    "run": "#expression-matrix.cwl",
                    "label": "Make expression matrix from quant vectors"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "outputSource": "#main/make_expression_matrix/expression_matrix",
                    "type": "File",
                    "label": "A hd5 file containing transcript by sample matrices of TPM and number of reads",
                    "id": "#main/expression_matrix"
                },
                {
                    "outputSource": "#main/fastqc/fastqc_dir",
                    "type": "Directory",
                    "label": "Directory of FastQC output files, mirroring input directory structure",
                    "id": "#main/fastqc_dir"
                },
                {
                    "outputSource": "#main/salmon-bulk/output_dir",
                    "type": "Directory",
                    "label": "Full output of `salmon quant`",
                    "id": "#main/salmon_output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "hubmap/salmon-grch38:latest",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/bulk_salmon_wrapper.py",
            "label": "Run Salmon quant tool on FASTQ input",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bulk-salmon.cwl/fastq_dir"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--threads"
                    },
                    "id": "#bulk-salmon.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "out"
                    },
                    "id": "#bulk-salmon.cwl/output_dir"
                }
            ],
            "id": "#bulk-salmon.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "hubmap/scrna-analysis:latest",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/make_expression_matrix.py",
            "label": "Takes gene expression vectors from several bulk RNA samples and makes them into a gene by sample matrix",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#expression-matrix.cwl/quant_dir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "expression_matrices.h5"
                    },
                    "id": "#expression-matrix.cwl/expression_matrix"
                }
            ],
            "id": "#expression-matrix.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Runs fastQC on each fastq file in fastq directory",
            "requirements": [
                {
                    "dockerPull": "hubmap/scrna-analysis:latest",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/fastqc_wrapper.py",
            "inputs": [
                {
                    "type": "Directory",
                    "doc": "Directory containing fastq files to be evaluated",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#fastqc.cwl/fastq_dir"
                },
                {
                    "type": "int",
                    "doc": "The number of threads to use for fastqc",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "fastqc_output"
                    },
                    "doc": "Individual graph files and additional data files containing the raw data from which plots were drawn.",
                    "id": "#fastqc.cwl/fastqc_dir"
                }
            ],
            "id": "#fastqc.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
